@@ -1,12 +1,13 @@
 __all__ = ["Browser", "BrowserSettings", "BrowserType", "CookieBannerSettings", "LoginCredentials",
-           "LoginForm", "PageLoadStrategy", "SearchSettings", "TimeoutSettings", "TimeoutStrategy"]
+           "LoginForm1Step", "LoginForm2Steps", "PageLoadStrategy", "SearchSettings", "TimeoutSettings", "TimeoutStrategy"]
 
 from .browser.__main__ import Browser
 from .model.browser.base.page_load_strategy import PageLoadStrategy
 from .model.browser.base.settings import BrowserSettings
 from .model.browser.base.type import BrowserType
 from .model.combo_settings.cookie_banner import CookieBannerSettings
-from .model.combo_settings.login import LoginCredentials, LoginForm
+from .model.combo_settings.login_credentials import LoginCredentials
+from .model.combo_settings.login_form import LoginForm1Step, LoginForm2Steps
 from .model.combo_settings.search import SearchSettings
 from .model.timeout_strategy import TimeoutSettings, TimeoutStrategy
 from .version import __version__  # noqa
