@@ -4,14 +4,16 @@ from selenium.webdriver.common.by import By
 from ...constant import timeout
 from ...exception.element import NoElementFoundException
 from ...exception.timeout import WaitForElementTimeoutException
+from ...model.type.xpath import XPath
 from ..wait.for_element import wait_for_element
 
 
 def click_button(driver: object, xpath: str, timeout: int = timeout.DEFAULT) -> None:
+    xpath = XPath(xpath)
     wait_for_element(driver, xpath, timeout)
     try:
-        button = driver.find_element(By.XPATH, xpath)
-        button.click()
+        element = driver.find_element(By.XPATH, xpath)  # type: ignore
+        element.click()
     except TimeoutException:
         raise WaitForElementTimeoutException(driver, xpath) from TimeoutException
     except NoSuchElementException:
