@@ -1,7 +1,8 @@
 from ...model.browser.base.driver import BrowserDriver
 from ...model.browser.base.settings import BrowserSettings
 from ...model.combo_settings.cookie_banner import CookieBannerSettings
-from ...model.combo_settings.login import LoginCredentials, LoginForm
+from ...model.combo_settings.login_credentials import LoginCredentials
+from ...model.combo_settings.login_form import LoginForm1Step, LoginForm2Steps
 from ...model.combo_settings.search import SearchSettings
 from ...model.driver_methods import DriverMethods
 from .cookie_banner import combo_cookie_banner
@@ -18,7 +19,7 @@ class ComboDriverMethods(DriverMethods):
 
         combo_cookie_banner(self._driver, settings)
 
-    def log_in(self, login_credentials: LoginCredentials, login_form: LoginForm) -> None:
+    def log_in(self, login_credentials: LoginCredentials, login_form: LoginForm1Step | LoginForm2Steps) -> None:
         """Standardised combination of methods to log in.
 
         wait_seconds: Extra seconds in addition to timeout to make sure the login is processed and that the user is redirected succesfully."""
