@@ -1,2 +1,2 @@
 def window_maximize(driver: object) -> None:
-    driver.maximize_window()
+    driver.maximize_window()  # type: ignore
