@@ -1,2 +1,2 @@
 def window_minimize(driver: object) -> None:
-    driver.minimize_window()
+    driver.minimize_window()  # type: ignore
