@@ -1,2 +1,2 @@
 def set_window_size(driver: object, width: int, height: int) -> None:
-    driver.set_window_size(width, height)
+    driver.set_window_size(width, height)  # type: ignore
